betty.gui.project module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.gui.project module

Provide project administration for the Graphical User Interface.

final class betty.gui.project.AddLocaleWindow

  Bases: `BettyMainWindow`

  A window to add a new project locale.

  Parameters:

    - app (`betty.app.App`)

    - parent (`PyQt6.QtCore.QObject` | `None`)

  __init__(app: betty.app.App, *, parent: PyQt6.QtCore.QObject | None = None)
    Parameters:

      - app (`betty.app.App`)

      - parent (`PyQt6.QtCore.QObject` | `None`)

  window_height = 250

    The window’s default height in pixels.

  property window_title: Localizable

    The human-readable short title of this window.

  window_width = 500

    The window’s default width in pixels.

final class betty.gui.project.ExtensionPane

  Bases: `LocalizedObject`, `QWidget`

  A configuration pane for a single extension.

  Parameters:

    - app (`betty.app.App`)

    - extension_type (`type`[`betty.app.extension.UserFacingExtension`])

  __init__(app: betty.app.App, extension_type: type[betty.app.extension.UserFacingExtension])
    Parameters:

      - app (`betty.app.App`)

      - extension_type (`type`[`betty.app.extension.UserFacingExtension`])

final class betty.gui.project.GeneralPane

  Bases: `LocalizedObject`, `QWidget`

  A pane to administer general project configuration.

  Parameters:

    app (`betty.app.App`)

  __init__(app: betty.app.App)
    Parameters:

      app (`betty.app.App`)

final class betty.gui.project.GenerateHtmlListForm

  Bases: `LocalizedObject`, `QWidget`

  A form widget to configure whether to generate entity listing HTML pages for the project’s entity types.

  Parameters:

    app (`betty.app.App`)

  __init__(app: betty.app.App)
    Parameters:

      app (`betty.app.App`)

final class betty.gui.project.GenerateWindow

  Bases: `BettyMainWindow`

  A window to control a site generation job.

  Parameters:

    - app (`betty.app.App`)

    - parent (`PyQt6.QtCore.QObject` | `None`)

  __init__(app: betty.app.App, *, parent: PyQt6.QtCore.QObject | None = None)
    Parameters:

      - app (`betty.app.App`)

      - parent (`PyQt6.QtCore.QObject` | `None`)

  closeEvent(a0: PyQt6.QtGui.QCloseEvent | None) → None
    Parameters:

      a0 (`PyQt6.QtGui.QCloseEvent` | `None`)

    Return type:

      `None`

  window_height = 100

    The window’s default height in pixels.

  property window_title: Localizable

    The human-readable short title of this window.

  window_width = 500

    The window’s default width in pixels.

final class betty.gui.project.LocalesConfigurationWidget

  Bases: `LocalizedObject`, `QWidget`

  A form widget to configuration project locales.

  Parameters:

    app (`betty.app.App`)

  __init__(app: betty.app.App)
    Parameters:

      app (`betty.app.App`)

final class betty.gui.project.LocalizationPane

  Bases: `LocalizedObject`, `QWidget`

  A pane for project localization configuration.

  Parameters:

    app (`betty.app.App`)

  __init__(app: betty.app.App)
    Parameters:

      app (`betty.app.App`)

final class betty.gui.project.ProjectWindow

  Bases: `BettyPrimaryWindow`

  A window to administer a project.

  Parameters:

    app (`betty.app.App`)

  __init__(app: betty.app.App)
    Parameters:

      app (`betty.app.App`)

  close() → bool
    Return type:

      `bool`

  generate() → None

    Generate a site for the project.

    Return type:

      `None`

  save_project_as() → None

    Copy this project and save it as a new one.

    Return type:

      `None`

  serve() → None

    Serve the project’s generated site.

    Return type:

      `None`

  show() → None
    Return type:

      `None`

  property window_title: Localizable

    The human-readable short title of this window.